@@ -25,7 +25,7 @@ class CoopsSosTest(unittest.TestCase):
 
     def test_coops_describe_sensor(self):
         self.c.features = ['8454000']
-        response = self.c.metadata()
+        response = self.c.metadata(output_format='text/xml;subtype="sensorML/1.0.1"')
         assert isinstance(response[0], SensorML)
 
     def test_raw_coops_get_observation(self):
@@ -89,4 +89,4 @@ class CoopsSosTest(unittest.TestCase):
         assert data[0]['datum_id'] == "urn:ogc:def:datum:epsg::5103"
         assert data[0]['date_time'] == "2012-10-01T01:00:00Z"
         assert data[0]['water_surface_height_above_reference_datum (m)'] == "0.863"
-        assert data[0]['vertical_position (m)'] == "1.818"
\ No newline at end of file
+        assert data[0]['vertical_position (m)'] == "1.818"
